# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['certipie', 'certipie.api', 'certipie.cli', 'certipie.cli.commands']

package_data = \
{'': ['*']}

install_requires = \
['click-didyoumean>=0.3.0,<0.4.0',
 'click-params>=0.1.2,<0.2.0',
 'click>=8.0.3,<9.0.0',
 'cryptography>=36.0.1,<37.0.0',
 'fastapi>=0.73.0,<0.74.0',
 'hypercorn>=0.13.2,<0.14.0',
 'idna>=3.3,<4.0',
 'python-multipart>=0.0.5,<0.0.6',
 'shellingham>=1.4.0,<2.0.0',
 'trio>=0.20.0,<0.21.0']

entry_points = \
{'console_scripts': ['cert = certipie.cli.main:cert']}

setup_kwargs = {
    'name': 'certipie',
    'version': '0.2.0',
    'description': 'A tool to create certificate signing request and self-signed certificates',
    'long_description': "# certipie\n\n[![Pypi version](https://img.shields.io/pypi/v/certipie.svg)](https://pypi.org/project/certipie/)\n![](https://github.com/lewoudar/certipie/workflows/CI/badge.svg)\n[![Coverage Status](https://codecov.io/gh/lewoudar/certipie/branch/main/graphs/badge.svg?branch=main)](https://codecov.io/gh/lewoudar/certipie)\n[![License Apache 2](https://img.shields.io/hexpm/l/plug.svg)](http://www.apache.org/licenses/LICENSE-2.0)\n\nA utility library to create certificate signing request and self-signed certificates.\n\n## Why?\n\nThere are three main reasons why I decide to do this:\n\n- I am a *nerd* who loves to code. Yeah, I need to be honest here, it was an opportunity for me to play with the\n  excellent [cryptography](https://cryptography.io/en/latest/) library.\n- I currently work in a company where we deal a lot with certificates, and I know it can be handy to have a simple tool\n  to generate certificate signing request, so I decide to create one.\n- When creating or working with network servers, we often need to test certificate handling, so it is convenient to have\n  a tool to quickly generate a self-signed certificate.\n\nNotes:\n\n- If you want a tool to handle a whole certificate life cycle for your project, consider using a library like\n  [certbot](https://eff-certbot.readthedocs.io/en/stable/).\n- If you just want a tool to create certificates on the fly during unit tests, consider using\n  [trustme](https://trustme.readthedocs.io/en/latest/).\n\n## Installation\n\nThe minimal python version supported is **3.9**. You can install the library using **pip** with the following command:\n\n```shell\n$ pip install certipie\n```\n\nYou can also use an alternative package manager like [poetry](https://python-poetry.org/docs/):\n\n```shell\n$ poetry add certipie\n```\n\n## Usage\n\nThere are three ways to use certipie.\n\n### The command line interface\n\nThis is probably the main way to use it. The project includes a convenient `cert` command line interface.\n\n```shell\n$ cert\nUsage: cert [OPTIONS] COMMAND [ARGS]...\n\n  A cli to generate certificate signing request and self-signed certificate\n  that can be used for testing purpose.\n\nOptions:\n  --version   Show the version and exit.\n  -h, --help  Show this message and exit.\n\nCommands:\n  auto-cert           Creates a self-signed certificate useful for tests.\n  csr                 Creates a certificate signing request file given...\n  install-completion  Install completion script for bash, zsh and fish...\n  rsa                 Creates a pair of private/public keys using the RSA...\n  server              Serves a swagger UI where you can perform the same...\n```\n\n#### install-completion\n\nThe first command you will want to use is `install-completion` like the name said will allow options and commands\ncompletion. The shells currently supported are **bash**, **fish** and **zsh**.\n\n```shell\n$ cert install-completion\n```\n\n#### rsa\n\nTo create a certificate signing request or a self-signed certificate, you need a private key. The `cert` command allows\nyou to create an **RSA** private key which is one of the most common (if not the most common) private keys used for this\ntype of operation.\n\n```shell\n$ cert rsa\nEnter the passphrase [passphrase]: \nRepeat for confirmation: \nThe pair of keys was successfully in ...\n```\n\nNote: On all commands, you can use `-h` option to get their usage documentation.\n\n#### csr\n\nThis commands helps you create a certificate signing request.\n\n```shell\n$ cert csr -f csr.pem\nOrganization: orga\nState: Ile-de-France\nCountry: FR\nCity: Paris\nName: site.com\nThe certificate signing request has been successfully created in /home/kevin/...\n```\n\nNotes:\n\n- In the previous example since no private key was passed as input, the `csr` command creates an **RSA** one with no\n  password in the same directory where the certificate signing request is created. If you want to provide one, use the\n  `-k` option and gives the path to the private key, e.g: `cert csr -k /path/to/private/key`. It is not mandatory that\n  the private key is of type RSA. In fact other algorithms are supported like DSA or elliptic curve. For a full list of\n  supported algorithms, look `PrivateKey` type in module `certipie.types`.\n- If you pass a key file, you will be prompted to give the password. If you don't provide a password to your private\n  key, just type `Enter` to continue.\n- The `--country` option must be a two-letters value. To know the two-letters code of a country, you can check this\n  [website](https://www.iban.com/country-codes).\n- The `--name` option value is used as the domain name to submit for the certificate signing request. In the previous\n  example, it will be `site.com`. Wildcards like `*.site.com` are supported.\n- If you want to include many domain names in the certificate signing request, not only the `--name` value, you can use\n  the `--alt-names` option like the following: `cert csr --alt-names=site.com,foo.site.com`. The values **must**\n  be separated by commas.\n\n#### auto-cert\n\nThis command helps you create a self-signed certificate useful when you want to test a network server like an HTTP\nserver.\n\n```shell\n$ cert auto-cert -f cert.pem --validity=360\nOrganization: orga\nState: Ile-de-France\nCountry: FR\nCity: Paris\nThe self-signed certificate has been successfully created in /home/kevin/...\n```\n\nNotes:\n\n- The notes from the `csr` command also applies here.\n- Since we often work on our own computer in this case, `localhost` is the default `--name` option.\n- `--alt-names` also accepts ip adresses and networks. You can have a value like the following:\n  `cert auto-cert --alt-names=localhost,192.168.1.0/24`.\n- `--validity` option represents the number of days the certificate will be valid. If not provided, it is **365**.\n\n#### server\n\nThis commands runs a server which serves a Swagger UI where you can perform the previous commands explained above. This\nis handy if you want non-technical staff to be able to use the command line features.\n\n```shell\n$ cert server\n```\n\nIf you open a browser on http://localhost:8000 you will see the swagger documentation.\n![](images/cert_api.png)\n\nUnder the hood the server used is [hypercorn](https://pgjones.gitlab.io/hypercorn). You can configure it passing a\n*toml* configuration file. To know all the settings available, refer to the\n[official documentation](https://pgjones.gitlab.io/hypercorn/how_to_guides/configuring.html).\n\n```shell\n$ cert server -c /path/to/toml/file\n```\n\n### The REST API\n\nFollowing the previous section about serving a swagger UI, if you think that it does not well suits your organization,\nyou can adjust it. The api is created using the [FastAPI](https://fastapi.tiangolo.com/) web framework. For example if\nyou want to integrate it in your own fastapi application, you can use the router provided by certipie.\n\nThis way you can adjust the url used for the certificate routes, for example `/certificate` instead of `/certs`, change\ndocumentation url, add some authentication to routes, etc...\nThe [router](https://fastapi.tiangolo.com/tutorial/bigger-applications/) concept is a powerful feature from FastAPI.\n\n```python\nfrom fastapi import FastAPI\nfrom certipie import router\n\napp = FastAPI(\n    title='certificate api',\n    description='Your description',\n    redoc_url=None,\n    docs_url='/documentation'\n)\napp.include_router(router, prefix='/certificate', tags=['certificate'])\n```\n\nTransform the api to suit your needs :)\n\n### The certipie API\n\nThe last way to leverage certipie is to interact programmatically with its api. The following functions are exposed:\n\n- `create_private_key`: Creates an RSA private key.\n- `get_public_key_from_private_key`: Extracts a public key from a private key.\n- `create_csr`: Creates a certificate signing request.\n- `create_auto_cert`: Creates a self-signed certificate.\n\nNormally the api usage should be straightforward. The behaviour is the same as the command line. You can also look at\ntests if you are blocked.\n\nHere is a snippet on how to create a certificate signing request using `create_csr`:\n\n```python\nfrom certipie import create_csr\n\ncreate_csr(\n  'csr.pem',\n  'FR',\n  'Ile-de-France',\n  'Paris',\n  'organization',\n  'site.com',\n  alternative_names=['site.com', 'foo.site.com'],\n  private_key='key.pem',\n  passphrase='passphrase'\n)\n```\n\nThere are two others objets exported:\n\n- `app`: The fastapi application used when running `cert server` command. It is exposed so that you can\n  [mount](https://fastapi.tiangolo.com/advanced/sub-applications/) it in another application if you want.\n- `PrivateKey`: The type annotation for all the private keys supported by the `cryptography` library.",
    'author': 'le_woudar',
    'author_email': 'lewoudar@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lewoudar/certipie',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
